==> nextcloud-app-deck-1:1.10.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/ka_GE.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "დასტა",
    "Personal" : "პირადი",
    "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
    "The board \"%s\" has been shared with you by %s." : "დაფა \"%s\" თქვენთან გაზიარდა %s-ისთვის.",
    "%s on %s" : "%s %s-ზე",
    "Finished" : "დასრულდა",
    "To review" : "მიმოხილვისთვის",
    "Action needed" : "საჭიროა ქმედება",
    "Later" : "მოგვიანებით",
    "Done" : "დასრულებულია",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
    "Cancel" : "უარყოფა",
    "Close" : "დახურვა",
    "File already exists" : "ფაილი უკვე არსებობს",
    "Do you want to overwrite it?" : "გსურთ მისი გადაწერა?",
    "Add card" : "ბარათის დამატება",
    "Filter by tag" : "ფილტრი ტეგებით",
    "Hide archived cards" : "არქივირებული ბარათების დამალვა",
    "Show archived cards" : "არქივირებული ბარათების ჩვენება",
    "Details" : "დეტალები",
    "Sharing" : "გაზიარება",
    "Tags" : "ტეგები",
    "Undo" : "დაბრუნება",
    "Can edit" : "შეუძლია შეცვალოს",
    "Can share" : "შეუძლია გააზიაროს",
    "Owner" : "მფლობელი",
    "Delete" : "წაშლა",
    "Edit" : "შეცვლა",
    "Members" : "წევრები",
    "Download" : "ჩამოტვირთვა",
    "Comments" : "კომენტარები",
    "Modified" : "შეიცვალა",
    "Created" : "შექმნილია",
    "Due date" : "დროისთვის",
    "Remove due date" : "მოაშორეთ დანიშნულების დრო",
    "Today" : "დღეს",
    "Tomorrow" : "ხვალ",
    "Save" : "შენახვა",
    "Reply" : "პასუხი",
    "Update" : "განახლება",
    "Description" : "აღწერა",
    "Formatting help" : "დახმარება ფორმატირებაზე",
    "(group)" : "(ჯგუფი)",
    "seconds ago" : "წამის წინ",
    "Archived boards" : "არქივირებული დაფები",
    "Shared with you" : "გაზიარებული თქვენთან",
    "Board details" : "დაფის დეტალები",
    "Edit board" : "დაფის შეცვლა",
    "Unarchive board" : "დაფის ამოღება",
    "Archive board" : "დაფის არქივირება",
    "No notifications" : "შეტყობინებები არაა",
    "Delete board" : "დაფის გაუქმება",
    "Share" : "გაზიარება"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-deck-1:1.11.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/ka_GE.js <==
OC.L10N.register(
    "deck",
    {
    "Deck" : "დასტა",
    "Personal" : "პირადი",
    "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
    "The board \"%s\" has been shared with you by %s." : "დაფა \"%s\" თქვენთან გაზიარდა %s-ისთვის.",
    "%s on %s" : "%s %s-ზე",
    "Finished" : "დასრულდა",
    "To review" : "მიმოხილვისთვის",
    "Action needed" : "საჭიროა ქმედება",
    "Later" : "მოგვიანებით",
    "Done" : "დასრულებულია",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "ატვირთული ფაილი აჭარბებს php.ini-ში დაყენებულ upload_max_filesize დირექტივას",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს HTML ფორამაში მითითებულ MAX_FILE_SIZE დირექტივას",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
    "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
    "Cancel" : "უარყოფა",
    "File already exists" : "ფაილი უკვე არსებობს",
    "Do you want to overwrite it?" : "გსურთ მისი გადაწერა?",
    "Add card" : "ბარათის დამატება",
    "Filter by tag" : "ფილტრი ტეგებით",
    "Hide archived cards" : "არქივირებული ბარათების დამალვა",
    "Show archived cards" : "არქივირებული ბარათების ჩვენება",
    "Details" : "დეტალები",
    "Sharing" : "გაზიარება",
    "Tags" : "ტეგები",
    "Activity" : "აქტივობა",
    "Undo" : "დაბრუნება",
    "Can edit" : "შეუძლია შეცვალოს",
    "Can share" : "შეუძლია გააზიაროს",
    "Owner" : "მფლობელი",
    "Delete" : "წაშლა",
    "Edit" : "შეცვლა",
    "Members" : "წევრები",
    "Download" : "ჩამოტვირთვა",
    "Comments" : "კომენტარები",
    "Modified" : "შეიცვალა",
    "Created" : "შექმნილია",
    "Save" : "შენახვა",
    "Reply" : "პასუხი",
    "Update" : "განახლება",
    "Created:" : "შექმნილია:",
    "Description" : "აღწერა",
    "Formatting help" : "დახმარება ფორმატირებაზე",
    "Remove due date" : "მოაშორეთ დანიშნულების დრო",
    "Completed" : "დასრულებული",
    "(group)" : "(ჯგუფი)",
    "seconds ago" : "წამის წინ",
    "Archived boards" : "არქივირებული დაფები",
    "Shared with you" : "გაზიარებული თქვენთან",
    "Board details" : "დაფის დეტალები",
    "Edit board" : "დაფის შეცვლა",
    "Unarchive board" : "დაფის ამოღება",
    "Archive board" : "დაფის არქივირება",
    "No notifications" : "შეტყობინებები არაა",
    "Delete board" : "დაფის გაუქმება",
    "Today" : "დღეს",
    "Tomorrow" : "ხვალ",
    "Close" : "დახურვა",
    "Share" : "გაზიარება",
    "Due date" : "დროისთვის"
},
"nplurals=2; plural=(n!=1);");
